req_matching_symbols – ShinyBroker

# req_matching_symbols

`req_matching_symbols(reqId, pattern)`

Create a request string for symbols that loosely match a pattern

## Parameters

Name | Type | Description | Default
--- | --- | --- | ---
`reqId` | int | Numeric identifier of the request | required
`pattern` | str | A string, like “AAPL”, “S&P 500” or “Vanguard” that you’d like to search for | required

## Examples

    import shinybroker as sb
    req_matching_symbols_msg = sb.req_market_data_type(3)
    print(req_matching_symbols_msg)